@@ -1,3 +1,10 @@
+import os
+import re
+
+_get_module_path = lambda path: os.path.normpath(os.path.join(os.getcwd(),
+                                                 os.path.dirname(__file__), path))
+
+"""
 direct_transform = {
     "个百分点": ["%", 1],
 
@@ -76,8 +83,8 @@ direct_transform = {
     "千瓦": ["W", 1000],
     "W": ["W", 1],
     "kW": ["W", 1000]
-
 }
+"""
 
 general_transform = {
     "万": 10000,
@@ -132,4 +139,22 @@ def cut_text_index(word_list):
         index_dict[i] = ind
         ind += len(word)
     index_dict[len(word_list)] = ind
-    return index_dict
\ No newline at end of file
+    return index_dict
+
+
+def _read_table(filename=_get_module_path("unit_transform")):
+    res = []
+    with open(filename, "r") as f:
+        for line in f:
+            if line.startswith("#"):
+                continue
+            line = re.split("\\s+", line.strip().lower())
+            res.append(line)
+    di = dict()
+    if len(res) > 0:
+        for i, line in enumerate(res):
+            if i == 0:
+                continue
+            else:
+                di[line[0]] = [line[1], float(line[2])]
+    return di
\ No newline at end of file
